---
home: true
heroImage: logo_transparent.png
actionText: Get Start ->
actionLink: /usage/
features:
  - title: 手軽に複雑なモデルが作成できます
    details: 基本的なモデルはもちろん Optuna によるパラメータチューニング・Seed Averagin・Stackingなどの複雑な処理を簡単に記述することができます。実装者はモデルの構造のみに集中してモデリングすることができます。
  - title: 自動ログ出力
    details: ディレクトリを指定するだけで自動的に学習ログを出力します。 feature importance や Accuracy などの各種メトリックを自分で記述する必要はありません。
  - title: 特徴作成を統一した記法で記述できます
    details: 学習・推論での記述方法が統一されているため、テストデータに対する特徴量がうまく作成できないといったエラーを防ぐことができます。
footer: © 2020 vivid.
---

# Install

```bash
pip install python-vivid
```
